@@ -1,7 +1,5 @@
 #!/usr/bin/perl -w
 
-use lib '../blib/lib', '../blib/arch';
-
 ### calculate_precision_and_recall_for_LSA.pl
 
 ##    This is a self-contained script for precision-and-recall calculatins with
@@ -81,5 +79,4 @@ $lsa->precision_and_recall_calculator('lsa');
 
 $lsa->display_precision_vs_recall_for_queries();
 
-$lsa->display_map_values_for_queries();
-
+$lsa->display_average_precision_for_queries_and_map();
