@@ -1,7 +1,5 @@
 #!/usr/bin/perl -w
 
-use lib '../blib/lib', '../blib/arch';
-
 ## calculate_similarity_matrix_for_all_docs.pl
 
 #  This script demonstrates how you can calculate the similarity matrix for
@@ -47,7 +45,7 @@ $vsm->generate_document_vectors();
 #my $similarity = $vsm->pairwise_similarity_for_docs("AddArray.java", "ArrayBasic.java");
 #print "Similarity score: $similarity\n";
 
-#    If you would the above calculation to be carried out with normalized
+#    If you wish that the above calculation to be carried out with normalized
 #    document vectors, uncomment the following two statements.  Again, you
 #    must change the arguments strings "AddArray.java" and "ArrayBasic.java"
 #    to the names of the documents you want to compare.
@@ -57,7 +55,6 @@ $vsm->generate_document_vectors();
 my @docs = @{$vsm->get_all_document_names()};
 
 
-
 my @similarity_matrix;
 foreach my $i (0..@docs-1) {
     my @one_row = ();
@@ -90,3 +87,5 @@ open my $fh, ">:encoding(utf8)", "SimilarityMatrix.csv"
 #$csv->print ($fh, $_) for @rows;
 $csv->print ($fh, $_) for @similarity_matrix;
 close $fh or die "SimilarityMatrix.csv: $!";
+
+print "\n\nThe similarity matrix has been written out to the CSV file 'SimilarityMatrix.csv'\n\n";
